@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1999-2020 The Octave Project Developers
+// Copyright (C) 1999-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -52,23 +52,25 @@ octave_cell : public octave_base_matrix<Cell>
 public:
 
   octave_cell (void)
-    : octave_base_matrix<Cell> (), cellstr_cache () { }
+    : octave_base_matrix<Cell> (), m_cellstr_cache () { }
 
   octave_cell (const Cell& c)
-    : octave_base_matrix<Cell> (c), cellstr_cache () { }
+    : octave_base_matrix<Cell> (c), m_cellstr_cache () { }
 
   octave_cell (const Array<std::string>& str)
     : octave_base_matrix<Cell> (Cell (str)),
-      cellstr_cache (new Array<std::string> (str)) { }
+      m_cellstr_cache (new Array<std::string> (str)) { }
 
   octave_cell (const octave_cell& c)
-    : octave_base_matrix<Cell> (c), cellstr_cache () { }
+    : octave_base_matrix<Cell> (c), m_cellstr_cache () { }
 
   ~octave_cell (void) = default;
 
   octave_base_value * clone (void) const { return new octave_cell (*this); }
   octave_base_value * empty_clone (void) const { return new octave_cell (); }
 
+  void break_closure_cycles (const std::shared_ptr<octave::stack_frame>& frame);
+
 #if 0
   octave_base_value * try_narrowing_conversion (void);
 #endif
@@ -105,11 +107,11 @@ public:
 
   void delete_elements (const octave_value_list& idx);
 
-  size_t byte_size (void) const;
+  std::size_t byte_size (void) const;
 
   octave_value sort (octave_idx_type dim = 0, sortmode mode = ASCENDING) const;
 
-  octave_value sort (Array<octave_idx_type> &sidx, octave_idx_type dim = 0,
+  octave_value sort (Array<octave_idx_type>& sidx, octave_idx_type dim = 0,
                      sortmode mode = ASCENDING) const;
 
   sortmode issorted (sortmode mode = UNSORTED) const;
@@ -134,7 +136,7 @@ public:
 
   bool is_true (void) const;
 
-  Cell cell_value (void) const { return matrix; }
+  Cell cell_value (void) const { return m_matrix; }
 
   octave_value_list list_value (void) const;
 
@@ -172,18 +174,20 @@ public:
 
   octave_value map (unary_mapper_t umap) const;
 
-  mxArray * as_mxArray (void) const;
+  mxArray * as_mxArray (bool interleaved) const;
 
-  // Unsafe.  This function exists to support the MEX interface.
+  // This function exists to support the MEX interface.
   // You should not use it anywhere else.
-  void * mex_get_data (void) const;
+  const void * mex_get_data (void) const;
 
 private:
 
   void clear_cellstr_cache (void) const
-  { cellstr_cache.reset (); }
+  { m_cellstr_cache.reset (); }
 
-  mutable std::unique_ptr<Array<std::string>> cellstr_cache;
+  //--------
+
+  mutable std::unique_ptr<Array<std::string>> m_cellstr_cache;
 
   DECLARE_OV_TYPEID_FUNCTIONS_AND_DATA
 };
